# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_disconnection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_disconnection.proto',
  package='packet',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\022DisconnectionProto',
  serialized_pb=b'\n\x1dpccodemao_disconnection.proto\x12\x06packet\"\x16\n\x14\x44isconnectionRequest\"\x17\n\x15\x44isconnectionResponseB2\n\x1c\x63om.ubtrobot.pccodemao.protoB\x12\x44isconnectionProtob\x06proto3'
)




_DISCONNECTIONREQUEST = _descriptor.Descriptor(
  name='DisconnectionRequest',
  full_name='packet.DisconnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=63,
)


_DISCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='DisconnectionResponse',
  full_name='packet.DisconnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=88,
)

DESCRIPTOR.message_types_by_name['DisconnectionRequest'] = _DISCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DisconnectionResponse'] = _DISCONNECTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DisconnectionRequest = _reflection.GeneratedProtocolMessageType('DisconnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTIONREQUEST,
  '__module__' : 'pccodemao_disconnection_pb2'
  # @@protoc_insertion_point(class_scope:packet.DisconnectionRequest)
  })
_sym_db.RegisterMessage(DisconnectionRequest)

DisconnectionResponse = _reflection.GeneratedProtocolMessageType('DisconnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTIONRESPONSE,
  '__module__' : 'pccodemao_disconnection_pb2'
  # @@protoc_insertion_point(class_scope:packet.DisconnectionResponse)
  })
_sym_db.RegisterMessage(DisconnectionResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

from mini.blockapi.base_api import BlockApiResultType
from mini.blockapi.block_content import QueryWiKi, WikiResponse
from mini.blockapi.block_content import StartTranslate, TranslateResponse
from mini.dns.dns_browser import WiFiDevice
from mini.pb2.cloudtranslate_pb2 import CN, EN
from test.test_connect import test_connect, shutdown, test_start_run_program
from test.test_connect import test_get_device_by_name


# 测试, 查询wiki
async def test_query_wiki():
    # query:查询关键字
    block: QueryWiKi = QueryWiKi(query='优必选')
    # response : WikiResponse
    (resultType, response) = await block.execute()

    print(f'test_query_wiki result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_query_wiki timetout'
    assert response is not None and isinstance(response, WikiResponse), 'test_query_wiki result unavailable'
    assert response.isSuccess, 'query_wiki failed'


# 测试翻译接口
async def test_start_translate():
    # query:
    # from_lan: 源语言
    # to_lan: 目标语言
    # platform: BAIDU, GOOGLE, TENCENT
    block: StartTranslate = StartTranslate(query="张学友", from_lan=CN, to_lan=EN)
    # response: TranslateResponse
    (resultType, response) = await block.execute()

    print(f'test_start_translate result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_start_translate timetout'
    assert response is not None and isinstance(response, TranslateResponse), 'test_start_translate result unavailable'
    assert response.isSuccess, 'start_translate failed'


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_query_wiki())
        asyncio.get_event_loop().run_until_complete(test_start_translate())
        asyncio.get_event_loop().run_until_complete(shutdown())



import asyncio

from mini.blockapi.block_observe import ObserveFaceRecognise
from mini.blockapi.block_sound import PlayTTS
from mini.dns.dns_browser import WiFiDevice
from mini.pb2.codemao_facerecognisetask_pb2 import FaceRecogniseTaskResponse
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


# 测试, 检测到注册的人脸,则上报事件, 如果陌生人,返回"stranger"
async def test_ObserveFaceRecognise():
    observer: ObserveFaceRecognise = ObserveFaceRecognise()

    # FaceRecogniseTaskResponse.faceInfos: [FaceInfoResponse]
    # FaceInfoResponse.id, FaceInfoResponse.name,FaceInfoResponse.gender,FaceInfoResponse.age
    # FaceRecogniseTaskResponse.isSuccess
    # FaceRecogniseTaskResponse.resultCode
    def handler(msg: FaceRecogniseTaskResponse):
        print(f"{msg}")
        if msg.isSuccess and msg.faceInfos:
            observer.stop()
            asyncio.create_task(__tts(msg.faceInfos[0].name))

    observer.set_handler(handler)
    observer.start()
    await asyncio.sleep(0)


async def __tts(name):
    await PlayTTS(text=f'你好， {name}').execute()
    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_ObserveFaceRecognise())
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())
